unit Unit4;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Buttons,ComCtrls,IniFiles;

type
  TForm4 = class(TForm)
    FontDialog1: TFontDialog;
    BitBtn1: TBitBtn;
    BitBtn2: TBitBtn;
    BitBtn3: TBitBtn;
    BitBtn4: TBitBtn;
    BitBtn5: TBitBtn;
    BitBtn6: TBitBtn;
    procedure BitBtn6Click(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormActivate(Sender: TObject);
   public

    function ReadFont(ini: TINIFile; section: string;
      default: TFont): TFont;
    procedure ReadForm(ini: TINIFile; Section: String; var Form: TForm);
    procedure WriteFont(ini: TIniFile; Section: String; Font: TFont);
    procedure WriteForm(ini: TINIFile; Section: String; Form: TForm);
    function GetFont(c: char): TFont;
    procedure GetFontAttr(c: char; A: TTextAttributes);
  end;

const FontCount = 6;
var
  Form4: TForm4;
  __ini: TINIFile;
  Fonts:array [1..FontCount] of TFont;

implementation

{$R *.dfm}

procedure TForm4.ReadForm(ini:TINIFile; Section:String; var Form:TForm);
begin
 Form.Left:= ini.ReadInteger(Section,'Left',Form.Left);
 Form.Top:= ini.ReadInteger(Section,'Top',Form.Top);
 Form.Height:= ini.ReadInteger(Section,'Height',Form.Height);
 Form.Width:= ini.ReadInteger(Section,'Width',Form.Width);
 Form.WindowState:= TWindowState(ini.ReadInteger(Section,'State',ord(Form.WindowState)));
 Form.FormStyle:= TFormStyle(ini.ReadInteger(Section,'FormStyle',ord(Form.FormStyle))); 
end;

function TForm4.ReadFont(ini:TINIFile; section:string; default:TFont): TFont;
var style: TFontStyles;
begin
 Result:=TFont.Create;
 Result.Size:=ini.ReadInteger(Section,'FontSize',Default.Size);
 Result.Color:=ini.ReadInteger(Section,'FontColor',Default.Color);
 Result.Name:=ini.ReadString(Section,'FontName',Default.Name);
 Result.Charset:=TFontCharset(ini.ReadInteger(Section,'FontCharset',Default.Charset));

if ini.ReadBool(Section,'FontBold',fsBold in Default.style) then
 include(style,fsBold)
else
 exclude(style,fsBold);

if ini.ReadBool(Section,'FontItalic',fsItalic in Default.style) then
 include(style,fsItalic)
else
 exclude(style,fsItalic);

if ini.ReadBool(Section,'FontUnderline',fsUnderline in Default.style) then
 include(style,fsUnderline)
else
 exclude(style,fsUnderline);

if ini.ReadBool(Section,'FontStrikeOut',fsStrikeOut in Default.style) then
 include(style,fsStrikeOut)
else
 exclude(style,fsStrikeOut);

Result.Style:=style;

end;

procedure TForm4.WriteFont(ini:TIniFile; Section:String; Font:TFont);
begin
 ini.WriteInteger(Section,'FontSize',Font.Size);
 ini.WriteInteger(Section,'FontColor',Font.Color);
 ini.WriteString(Section,'FontName',Font.Name);
 ini.WriteInteger(Section,'FontCharset',Font.Charset);

 ini.WriteBool(Section,'FontBold',fsBold in Font.style);
 ini.WriteBool(Section,'FontItalic',fsItalic in Font.style);
 ini.WriteBool(Section,'FontUnderline',fsUnderline in Font.style);
 ini.WriteBool(Section,'FontStrikeOut',fsStrikeOut in Font.style);
end;

procedure TForm4.WriteForm(ini:TINIFile; Section:String; Form:TForm);
begin
 ini.WriteInteger(Section,'State',ord(Form.WindowState));
 ini.WriteInteger(Section,'FormStyle',ord(Form.FormStyle));

 if Form.WindowState = wsNormal then begin
  ini.WriteInteger(Section,'Left',Form.Left);
  ini.WriteInteger(Section,'Top',Form.Top);
  ini.WriteInteger(Section,'Height',Form.Height);
  ini.WriteInteger(Section,'Width',Form.Width);
 end;
end;

procedure TForm4.BitBtn6Click(Sender: TObject);
var i:integer;
begin
 if Sender = BitBtn1 then i:=1
 else if Sender = BitBtn2 then i:=2
 else if Sender = BitBtn3 then i:=3
 else if Sender = BitBtn4 then i:=4
 else if Sender = BitBtn5 then i:=5
 else if Sender = BitBtn6 then i:=6;

 FontDialog1.Font:=Fonts[i];
 if FontDialog1.Execute then begin
  Fonts[i]:=FontDialog1.Font;
  TBitBtn(Sender).Font:=Fonts[i];
 end;
end;

function TForm4.GetFont(c:char):TFont;
begin
 case c of
 '+','-','=','''': Result:=Fonts[1];
 '*','/': Result:=Fonts[2];
 '^','@': Result:=Fonts[3];
 '0'..'9': Result:=Fonts[4];
 '('..')': Result:=Fonts[6];
 else  Result:=Fonts[5];
 end;
end;

procedure TForm4.GetFontAttr(c:char; A:TTextAttributes);
var F:TFont;
begin
 F:=GetFont(c);

 A.Color:=F.Color;
 A.Name:=F.Name;
 A.Charset:=F.Charset;
 A.Size:=F.Size;
 A.Style:=F.Style;
end;

procedure TForm4.FormClose(Sender: TObject; var Action: TCloseAction);
begin
 WriteForm(__ini,'Form4',Form4);
end;

procedure TForm4.FormActivate(Sender: TObject);
begin
 ReadForm(__ini,'Form4',TForm(Form4));
 BitBtn1.Font:=Fonts[1];
 BitBtn2.Font:=Fonts[2];
 BitBtn3.Font:=Fonts[3];
 BitBtn4.Font:=Fonts[4];
 BitBtn5.Font:=Fonts[5];
 BitBtn6.Font:=Fonts[6];
end;

end.
